# Unit Tests
Run unit tests with `pytest unit`

# Integration Tests
Run integration tests with `pytest integration`

# Note
Running within `unit` or `integration` directories will fail to find the filename.wav file.
